@@ -63,15 +63,15 @@
 #' # Salutary note: You need well fitting models with correct betas in the data
 #' # for power to be valid.
 #' # tryHard helps ensure this, as does the default nSim= 4000 pair data.
-#' # Power is important to get right, so I recommend using tryHard = "yes"
-#' power.ACE.test(AA= .5, CC= 0, update = "a", tryHard= "yes")
+#' # Power is important to get right, so I recommend using tryHard = "yes" (the default)
+#' power.ACE.test(AA= .5, CC= 0, update = "a")
 #' 
 #' # =====================
 #' # = Power to detect C =
 #' # =====================
 #' 
 #' # 102 of each of MZ and DZ pairs for 80% power.
-#' power.ACE.test(AA= .5, CC= .3, update = "c", tryHard= "yes")
+#' power.ACE.test(AA= .5, CC= .3, update = "c")
 #'
 #' # ========================================
 #' # = Set 'a' to a fixed, but non-zero value =
@@ -126,7 +126,7 @@
 #' # ====================
 #' # 1. tryHard
 #' 
-#' power.ACE.test(update = "a", AA= .5, CC= 0, tryHard= "yes")
+#' power.ACE.test(update = "a", AA= .5, CC= 0, tryHard= "no")
 #'
 #' # 2. toggle optimizer
 #' power.ACE.test(update= "a", AA= .5, CC= 0, optimizer= "SLSQP")
@@ -137,7 +137,7 @@
 #'
 #' }
 #'
-power.ACE.test <- function(AA= .5, CC= 0, EE= NULL, update = c("a", "c", "a_after_dropping_c"), value = 0, n = NULL, MZ_DZ_ratio = 1, sig.level = 0.05, power = .8, method = c("ncp", "empirical"), search = FALSE, tryHard = c("no", "yes", "mxTryHard", "mxTryHardOrdinal", "mxTryHardWideSearch"), optimizer = NULL, nSim=4000){
+power.ACE.test <- function(AA= .5, CC= 0, EE= NULL, update = c("a", "c", "a_after_dropping_c"), value = 0, n = NULL, MZ_DZ_ratio = 1, sig.level = 0.05, power = .8, method = c("ncp", "empirical"), search = FALSE, tryHard = c("yes", "no", "ordinal", "search"), optimizer = NULL, nSim=4000){
 	# # TODO why not equivalent to this?
 	# # https://genepi.qimr.edu.au//general/TwinPowerCalculator/twinpower.cgi
 	#
